@@ -1173,7 +1173,8 @@ class Update(MethodsInterface):
         hosts = self.clVars.Get("update.cl_update_binhost_host")
         if not hosts:
             self.clVars.Delete('cl_update_binhost', location="system")
-            raise UpdateError(_("Update server is unavailable"))
+            raise UpdateError(_("Failed to find the server with "
+                                "appropriate updates"))
         if write_binhost:
             if hosts[0] != self.clVars.Get('update.cl_update_binhost'):
                 self.refresh_binhost = True
@@ -1181,9 +1182,7 @@ class Update(MethodsInterface):
             new_ts = self.clVars.Get("update.cl_update_binhost_timestamp")
             if new_ts:
                 new_ts = new_ts[0]
-                old_ts = self.clVars.Get("update.cl_update_last_timestamp")
-                if new_ts.isdigit() and (not old_ts.isdigit() or
-                                                 int(new_ts) > int(old_ts)):
+                if new_ts.isdigit():
                     ini = SystemIni(self.clVars)
                     ini.setVar('update', {'last_update': new_ts})
         if self.clVars.Get('cl_action') == 'sync':
@@ -1226,10 +1225,12 @@ class Update(MethodsInterface):
                 self.clVars.Set(varname, new_value, force=True)
             if not changes:
                 self.clVars.Delete('cl_update_binhost', location="system")
-                raise UpdateError(_("Update server is unavailable"))
+                raise UpdateError(_("Failed to find the server with "
+                                    "appropriate updates"))
         except DataVarsError:
             self.clVars.Delete('cl_update_binhost', location="system")
-            raise UpdateError(_("Update server is unavailable"))
+            raise UpdateError(_("Failed to find the server with "
+                                "appropriate updates"))
         return True
 
     def drop_binhosts(self, dv):
